John,

Please apply to wireless-2.6.

Thanks, Larry

===========================================

This patch sets the floor of wireless level (signal) and noise at -110 dBm, which makes them be comatible with RCPI, as discussed by Simon Barber. With this change, bcm43xx-softmac and bcm43xx-d80211 behave the same.

Signed-Off-By: Larry Finger <[EMAIL PROTECTED]>

diff --git a/drivers/net/wireless/bcm43xx/bcm43xx_wx.c 
b/drivers/net/wireless/bcm43xx/bcm43xx_wx.c
index 1d3a3aa..888077f 100644
--- a/drivers/net/wireless/bcm43xx/bcm43xx_wx.c
+++ b/drivers/net/wireless/bcm43xx/bcm43xx_wx.c
@@ -229,8 +229,8 @@ static int bcm43xx_wx_get_rangeparams(st
        range->throughput = 27 * 1000 * 1000;

        range->max_qual.qual = 100;
-       range->max_qual.level = 152; /* set floor at -104 dBm (152 - 256) */
-       range->max_qual.noise = 152;
+       range->max_qual.level = 146; /* set floor at -110 dBm (146 - 256) */
+       range->max_qual.noise = 146;
        range->max_qual.updated = IW_QUAL_ALL_UPDATED;

        range->avg_qual.qual = 50;
-
To unsubscribe from this list: send the line "unsubscribe netdev" in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to